==> localres-1.0.tar.gz: localres-1.0/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup
from os import path

# Get the long description from the README file
here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding = 'utf-8') as f:
    readme = f.read()

setup(
    name = 'localres',
    version = '1.0',

    description = 'Plot a histogram of local resolution values from a local resolution map of a cryo-EM reconstruction from RELION.',
    long_description = readme,
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/Guillawme/localres',

    author = 'Guillaume Gaullier',
    author_email = 'contact@gaullier.org',

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Visualization',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'Environment :: Console',
        'Natural Language :: English'
    ],
    keywords = 'cryo-EM map local resolution histogram visualization',

    py_modules = ["localres"],

    python_requires = '>=3.7',
    install_requires = [
        'mrcfile>=1.1.2',
        'numpy>=1.17.4',
        'matplotlib>=3.1.2',
        'click>=7.0'
    ],

    entry_points = {
        'console_scripts': [
            'localres=localres:cli',
        ]
    },

    project_urls = {
        'Bug Reports': 'https://github.com/Guillawme/localres/issues',
        'Source': 'https://github.com/Guillawme/localres'
    }
)

==> localres-1.1.tar.gz: localres-1.1/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup
from os import path

# Get the long description from the README file
here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding = 'utf-8') as f:
    readme = f.read()

setup(
    name = 'localres',
    version = '1.1',

    description = 'Plot a histogram of local resolution values from a local resolution map of a cryo-EM reconstruction from RELION.',
    long_description = readme,
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/Guillawme/localres',

    author = 'Guillaume Gaullier',
    author_email = 'contact@gaullier.org',

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Visualization',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'Environment :: Console',
        'Natural Language :: English'
    ],
    keywords = 'cryo-EM map local resolution histogram visualization',

    py_modules = ["localres"],

    python_requires = '>=3.7',
    install_requires = [
        'click>=7.0',
        'matplotlib>=3.1.1',
        'mrcfile>=1.1.2',
        'numpy>=1.17.3'
    ],

    entry_points = {
        'console_scripts': [
            'localres=localres:cli'
        ]
    },

    project_urls = {
        'Bug Reports': 'https://github.com/Guillawme/localres/issues',
        'Source': 'https://github.com/Guillawme/localres'
    }
)
